@@ -312,13 +312,13 @@ LockStruct  LockProcs[] =
 	{"maze3d",
 	 20000, 1, 2, 1, 64, 1.0, "",
 	 "Shows a 3D maze", 0, NULL, "#ifdef USE_GL"},
-	{"moebius",
-	 30000, 1, 1, 1, 64, 1.0, "",
-	 "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL, "#ifdef USE_GL"},
 	{"mball",
 	 100000, -30, 5, -6, 64, 1.0, "",
 	 "Shows an auto-solving Masterball puzzle", 0, NULL, "#ifdef USE_GL"},
-	{(char *) "molecule",
+	{"moebius",
+	 30000, 1, 1, 1, 64, 1.0, "",
+	 "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL, "#ifdef USE_GL"},
+	{"molecule",
 	 50000, 1, 20, 1, 64, 1.0, "",
 	 "Draws molecules", 0, NULL, "#ifdef USE_GL"},
 	{"morph3d",
@@ -341,7 +341,7 @@ LockStruct  LockProcs[] =
 	 "Shows a man with a big nose runs around spewing out messages", 0, NULL, NULL},
 #ifdef USE_GL
 	{"oct",
-	 100000, -30, 5, -5, 64, 1.0, "",
+	 100000, -30, 5, -6, 64, 1.0, "",
 	 "Shows an auto-solving octahedron puzzle", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"pacman",
@@ -369,7 +369,7 @@ LockStruct  LockProcs[] =
 	 "Shows a puzzle being scrambled and then solved", 0, NULL, NULL},
 #ifdef USE_GL
 	{"pyraminx",
-	 100000, -30, 5, -5, 64, 1.0, "",
+	 100000, -30, 5, -6, 64, 1.0, "",
 	 "Shows an auto-solving Pyraminx puzzle", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"pyro",
