@@ -56,7 +56,7 @@ static const char sccsid[] = "@(#)ant3d.c	5.13 2004/07/23 xlockmore";
 #define FONT_WIDTH 15
 
 /*-
- * neighbors of 0 randomizes it for 6, 8, 12, 14, 18, 20, 26
+ * neighbors of 0 randomizes it for 6, 12
  */
 #define DEF_NEIGHBORS  "0"      /* choose random value */
 #define DEF_RULE "A" /* All rules */
@@ -73,8 +73,7 @@ static XrmOptionDescRec opts[] =
 	{(char *) "+label", (char *) ".ant3d.label", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-neighbors", (char *) ".ant3d.neighbors", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-rule", (char *) ".ant3d.rule", XrmoptionSepArg, (caddr_t) NULL},
-	{(char *) "-eyes", (char *) ".ant3d.eyes", XrmoptionNoArg, (caddr_t) "on"}
-,
+	{(char *) "-eyes", (char *) ".ant3d.eyes", XrmoptionNoArg, (caddr_t) "on"},
         {(char *) "+eyes", (char *) ".ant3d.eyes", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
@@ -87,7 +86,7 @@ static argtype vars[] =
 static OptionStruct desc[] =
 {
 	{(char *) "-/+label", (char *) "turn on/off rule labeling"},
-	{(char *) "-neighbors num", (char *) "cubes 6, 8, 14, 18, 20, 26, or rhombic dodecahedron 12"},
+	{(char *) "-neighbors num", (char *) "cubes 6 or rhombic dodecahedron 12"},
 	{(char *) "-rule string", (char *) "base 4 string for Turk's Ant"},
 	{(char *) "-/+eyes", (char *) "turn on/off eyes"}
 };
@@ -196,7 +195,7 @@ typedef struct {
 } antfarm3dstruct;
 
 static char plots[] =
-{12, 26};
+{6, 12};
 #define NEIGHBORKINDS ((long) (sizeof plots / sizeof *plots))
 
 /* Coordinate ant moves */
