@@ -19,6 +19,7 @@
  *       "juggle" to "juggler3d".  The old "juggler3d" hack is gone.
  *
  * Revision History
+ * 30-Apr-2024: bagleyd added -bbags like his juggling balls
  * 09-Aug-2009: jwz: converted from Xlib to OpenGL.
  * 13-Dec-2004: [TDA] Use -cycles and -count in a rational manner.
  *              Add -rings, -bballs.  Add -describe.  Finally made
@@ -187,6 +188,7 @@
 #define DEF_REAL "True"
 #define DEF_DESCRIBE "True"
 
+#define DEF_BBAGS "True" /* Use Bean Bags */
 #define DEF_BALLS "True" /* Use Balls */
 #define DEF_CLUBS "True" /* Use Clubs */
 #define DEF_TORCHES "True" /* Use Torches */
@@ -201,6 +203,7 @@ static Bool uni;
 #endif
 static Bool real;
 static Bool describe;
+static Bool bbags;
 static Bool balls;
 static Bool clubs;
 static Bool torches;
@@ -220,6 +223,8 @@ static XrmOptionDescRec opts[] = {
   {"+real",     ".juggle.real",     XrmoptionNoArg,  "off" },
   {"-describe", ".juggle.describe", XrmoptionNoArg,  "on"  },
   {"+describe", ".juggle.describe", XrmoptionNoArg,  "off" },
+  {"-bbags",    ".juggle.bbags",    XrmoptionNoArg,  "on"  },
+  {"+bbags",    ".juggle.bbags",    XrmoptionNoArg,  "off" },
   {"-balls",    ".juggle.balls",    XrmoptionNoArg,  "on"  },
   {"+balls",    ".juggle.balls",    XrmoptionNoArg,  "off" },
   {"-clubs",    ".juggle.clubs",    XrmoptionNoArg,  "on"  },
@@ -243,7 +248,8 @@ static argtype vars[] = {
 #endif
   { &real,     "real",     "Real",     DEF_REAL,     t_Bool   },
   { &describe, "describe", "Describe", DEF_DESCRIBE, t_Bool   },
-  { &balls,    "balls",    "Clubs",    DEF_BALLS,    t_Bool   },
+  { &bbags,    "bbags",    "BBags" ,   DEF_BBAGS,    t_Bool   },
+  { &balls,    "balls",    "Balls",    DEF_BALLS,    t_Bool   },
   { &clubs,    "clubs",    "Clubs",    DEF_CLUBS,    t_Bool   },
   { &torches,  "torches",  "Torches",  DEF_TORCHES,  t_Bool   },
   { &knives,   "knives",   "Knives",   DEF_KNIVES,   t_Bool   },
@@ -261,6 +267,7 @@ static OptionStruct desc[] =
 #endif
   { "-/+real",         "Real-time" },
   { "-/+describe",     "turn on/off pattern descriptions." },
+  { "-/+bbags",        "turn on/off Bean Bags." },
   { "-/+balls",        "turn on/off Balls." },
   { "-/+clubs",        "turn on/off Clubs." },
   { "-/+torches",      "turn on/off Flaming Torches." },
@@ -340,10 +347,10 @@ typedef struct trace {
  *******************************************************************/
 typedef int (DrawProc)(ModeInfo*, unsigned long, Trace *);
 
-static DrawProc show_ball, show_europeanclub, show_torch, show_knife;
+static DrawProc show_bbag, show_ball, show_europeanclub, show_torch, show_knife;
 static DrawProc show_ring, show_bball;
 
-typedef enum {BALL, CLUB, TORCH, KNIFE, RING, BBALLS,
+typedef enum {BBAG, BALL, CLUB, TORCH, KNIFE, RING, BBALL,
               NUM_OBJECT_TYPES} ObjType;
 
 #define OBJMIXPROB 20   /* inverse of the chances of using an odd
@@ -359,6 +366,13 @@ static const struct {
   double    cor;      /* Coefficient of Restitution.  perfect bounce = 1 */
   double    weight;          /* Heavier objects don't get thrown as high */
 } ObjectDefs[] = {
+  { /* Bean Bags */
+	show_bbag,
+	0,
+	1,
+	0,
+	1.0,
+  },
   { /* Ball */
 	show_ball,
 	0,
@@ -606,6 +620,7 @@ typedef struct {
   rotator *rot;
   trackball_state *trackball;
   Bool button_down_p;
+  Bool patch;
 
   double        scale;
   double        cx;
@@ -996,12 +1011,13 @@ choose_object(void) {
   ObjType o;
   for (;;) {
 	o = (ObjType)NRAND((ObjType)NUM_OBJECT_TYPES);
+	if(bbags && o == BBAG) break;
 	if(balls && o == BALL) break;
 	if(clubs && o == CLUB) break;
 	if(torches && o == TORCH) break;
 	if(knives && o == KNIFE) break;
 	if(rings && o == RING) break;
-	if(bballs && o == BBALLS) break;
+	if(bballs && o == BBALL) break;
   }
   return o;
 }
@@ -1056,7 +1072,7 @@ lob(ModeInfo *mi)
 		/* Balls can change divisions at each throw */
                 /* no, that looks stupid. -jwz */
                 if (t->divisions < 1)
-                  t->divisions = 2 * (NRAND(2) + 1);
+                  t->divisions = 2 * (NRAND(4) + 1);
 
 		/* search forward for next catch in this hand */
 		for (p = t->next; t->handlink == NULL; p = p->next) {
@@ -2056,7 +2072,8 @@ striped_unit_sphere (int stacks, int slices,
       theta1 = j       * (M_PI+M_PI) / stacks2 - M_PI_2;
       theta2 = (j + 1) * (M_PI+M_PI) / stacks2 - M_PI_2;
 
-      glMaterialfv (GL_FRONT, GL_AMBIENT_AND_DIFFUSE,
+      if (stripes != -1) /* octahedron ball */
+        glMaterialfv (GL_FRONT, GL_AMBIENT_AND_DIFFUSE,
                     ((j == 0 || j == stacks-1 ||
                      j % (stacks / (stripes+1)))
                      ? color1 : color2));
@@ -2064,6 +2081,11 @@ striped_unit_sphere (int stacks, int slices,
       glBegin (wire_p ? GL_LINE_LOOP : GL_TRIANGLE_STRIP);
       for (i = 0; i <= slices; i++)
         {
+          if (stripes == -1) /* octahedron ball */
+            glMaterialfv (GL_FRONT, GL_AMBIENT_AND_DIFFUSE,
+                    (((j >= stacks / 2 && (i % (slices / 2) < (slices / 4))) ||
+                    (j < stacks / 2 && (i % (slices / 2) >= (slices / 4))))
+                    ? color1 : color2));
           theta3 = i * (M_PI+M_PI) / slices;
 
           if (wire_p && i != 0)
@@ -2104,7 +2126,43 @@ striped_unit_sphere (int stacks, int slices,
   return polys;
 }
 
+static int
+show_bbag(ModeInfo *mi, unsigned long color, Trace *s)
+{
+  int polys = 0;
+  jugglestruct *sp = &juggles[MI_SCREEN(mi)];
+  /*int offset = (int)(s->angle*64*180/M_PI);*/
+  short x = (short)(SCENE_WIDTH/2 + s->x * sp->scale);
+  short y = (short)(SCENE_HEIGHT - s->y * sp->scale);
+  GLfloat gcolor1[4] = { 0, 0, 0, 1 };
+  GLfloat gcolor2[4] = { 0, 0, 0, 1 };
+  int slices = 24;
 
+  /* Avoid wrapping */
+  if(s->y*sp->scale >  SCENE_HEIGHT * 2) return 0;
+
+  gcolor1[0] = MI_COLOR_red   / 65536.0;
+  gcolor1[1] = MI_COLOR_green / 65536.0;
+  gcolor1[2] = MI_COLOR_blue  / 65536.0;
+
+  gcolor2[0] = gcolor1[0] / 3;
+  gcolor2[1] = gcolor1[1] / 3;
+  gcolor2[2] = gcolor1[2] / 3;
+
+  {
+    GLfloat scale = BALLRADIUS;
+    glPushMatrix();
+    glTranslatef(x, y, 0);
+    glScalef(scale, scale, scale);
+
+    glRotatef (s->angle / M_PI*180, 1, 1, 0);
+
+    polys += striped_unit_sphere (slices, slices, -1,
+                                  gcolor1, gcolor2, MI_IS_WIREFRAME(mi));
+    glPopMatrix();
+  }
+  return polys;
+}
 
 static int
 show_ball(ModeInfo *mi, unsigned long color, Trace *s)
@@ -2670,7 +2728,7 @@ change_juggler3d(ModeInfo * mi)
 
   /* Pick the current object theme */
   sp->objtypes = choose_object();
-
+  sp->patch = NRAND(2);
   refill_juggle(mi);
 
   MI_POLYGONCOUNT(mi) += show_figure(mi, True);
@@ -2756,10 +2814,12 @@ init_juggler3d (ModeInfo * mi)
                             spin_accel, wander_speed, False);
     sp->trackball = gltrackball_init (True);
   }
+  sp->patch = NRAND(2);
 
   if (only && *only && strcmp(only, " ")) {
-    balls = clubs = torches = knives = rings = bballs = False;
-    if (!strcasecmp (only, "balls"))   balls   = True;
+    bbags = balls = clubs = torches = knives = rings = bballs = False;
+    if (!strcasecmp (only, "bbags"))   bbags   = True;
+    else if (!strcasecmp (only, "balls"))   balls   = True;
     else if (!strcasecmp (only, "clubs"))   clubs   = True;
     else if (!strcasecmp (only, "torches")) torches = True;
     else if (!strcasecmp (only, "knives"))  knives  = True;
@@ -2767,8 +2827,8 @@ init_juggler3d (ModeInfo * mi)
     else if (!strcasecmp (only, "bballs"))  bballs  = True;
     else {
       (void) fprintf (stderr,
-               "Juggle: -only must be one of: balls, clubs, torches, knives,\n"
-               "\t rings, or bballs (not \"%s\")\n", only);
+               "Juggle: -only must be one of: bbags, balls, clubs, torches,\n"
+               "\t knives, rings, or bballs (not \"%s\")\n", only);
 #ifdef STANDALONE /* xlock mustn't exit merely because of a bad argument */
       exit (1);
 #endif
@@ -2802,7 +2862,7 @@ init_juggler3d (ModeInfo * mi)
 	sp->Gr = -GRAVITY(3 * sp->arm[0][RIGHT][SHOULDER].y,
 					  7 * THROW_CATCH_INTERVAL);
 
-	if(!balls && !clubs && !torches && !knives && !rings && !bballs)
+	if(!bbags && !balls && !clubs && !torches && !knives && !rings && !bballs)
 	  balls = True; /* Have to juggle something! */
 
 	/* create circular trajectory list */
