@@ -44,6 +44,17 @@ static const char sccsid[] = "@(#)morph3d.c	5.01 2001/03/01 xlockmore";
  * Marcelo F. Vianna (Feb-13-1997)
  *
  * Revision History:
+ * 01-Mar-2025: Many tweaks made possible due to computing power advances after
+ *              that many years:
+ *              - Increased number of triangles on polyhedra faces and spheres;
+ *              - Made animation smoother by reducing its granularity per cycle
+ *                (mp->step) and reducing the delay between each step;
+ *              - Fixed invalid references to MODE_moebius where it should be
+ *                MODE_morph3d (an unnoticed bug after decades).
+ *              OBS: Interesting experience to be messing with my own code
+ *              after almost 30 years since the first version and 23 years after
+ *              the last previous change. 
+ *              <marcelofvianna AT gmail.com>
  * 05-Apr-2002: Removed all gllist uses (fix some bug with nvidia driver)
  * 01-Mar-2001: Added FPS stuff E.Lassauge <lassauge AT users.sourceforge.net>
  * 27-Jul-1997: Speed ups by Marcelo F. Vianna.
@@ -118,7 +129,7 @@ this angle is the same of the tetrahedron one:
      | 2*ARCSIN(sqrt(2)/sqrt(3)) = 109.47122063449069174 degrees |
      +-----------------------------------------------------------+
 For the dodecahedron it's a little bit harder because it's only relationship
-with the cube is useless to us. So we need to solve the problem by another
+with the cube is useless to us. So we need to solve the problem in a different
 way. The concept of Face radius also exists on 2D polygons with the name
 Edge radius:
   Edge Radius For Pentagon (ERp)
@@ -215,8 +226,8 @@ Update May-24-2005
 #endif
 
 #ifdef STANDALONE
-# define MODE_moebius
-# define DEFAULTS	"*delay: 1000 \n" \
+# define MODE_morph3d
+# define DEFAULTS	"*delay: 10000 \n" \
 			"*count: 0 \n" \
 
 #define free_morph3d 0
@@ -227,7 +238,7 @@ Update May-24-2005
 # include "visgl.h"
 #endif /* !STANDALONE */
 
-#ifdef MODE_moebius
+#ifdef MODE_morph3d
 
 ENTRYPOINT ModeSpecOpt morph3d_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
@@ -236,7 +247,7 @@ ENTRYPOINT ModeSpecOpt morph3d_opts =
 ModStruct   morph3d_description =
 {"morph3d", "init_morph3d", "draw_morph3d", "release_morph3d",
  "draw_morph3d", "change_morph3d", (char *) NULL, &morph3d_opts,
- 1000, 0, 1, 1, 64, 1.0, "",
+ 10000, 0, 1, 1, 64, 1.0, "",
  "Shows GL morphing polyhedra", 0, NULL};
 
 #endif
@@ -248,11 +259,11 @@ ModStruct   morph3d_description =
 #define sqr(A)                     ((A)*(A))
 
 /* Increasing this values produces better image quality, the price is speed. */
-#define tetradivisions             23
-#define cubedivisions              20
-#define octadivisions              21
-#define dodecadivisions            10
-#define icodivisions               15
+#define tetradivisions             100 /* 23 */
+#define cubedivisions              100 /* 20 */
+#define octadivisions              100 /* 21 */
+#define dodecadivisions            100 /* 10 */
+#define icodivisions               100 /* 15 */
 
 #define tetraangle                 109.47122063449069174
 #define cubeangle                  90.000000000000000000
@@ -979,7 +990,7 @@ draw_morph3d(ModeInfo * mi)
 	if (MI_IS_FPS(mi)) do_fps (mi);
 	glXSwapBuffers(display, window);
 
-	mp->step += 0.05;
+	mp->step += 0.015;
 }
 
 ENTRYPOINT void
