@@ -192,7 +192,7 @@ typedef struct ModeInfo_s {
 
 #define MI_DISPLAY(mi)		((mi)->windowinfo.display)
 #define MI_SCREEN(mi)		((mi)->windowinfo.screen)
-#define MI_SCREENPTR(mi)      	((mi)->windowinfo.screenptr)
+#define MI_SCREENPTR(mi)	((mi)->windowinfo.screenptr)
 #define MI_REAL_SCREEN(mi)	((mi)->windowinfo.real_screen)
 #define MI_NUM_SCREENS(mi)	((mi)->windowinfo.num_screens)
 #define MI_MAX_SCREENS(mi)	((mi)->windowinfo.max_screens)
@@ -205,8 +205,8 @@ typedef struct ModeInfo_s {
 #define MI_SET_FLAG_STATE(mi,f,bool) ((mi)->windowinfo.flags = \
 					(bool) ? (mi)->windowinfo.flags | f \
 					: (mi)->windowinfo.flags & ~(f))
-#define MI_FLAG_IS_SET(mi,f) 	((mi)->windowinfo.flags & f)
-#define MI_FLAG_NOT_SET(mi,f) 	( ! MI_FLAG_IS_SET(mi,f))
+#define MI_FLAG_IS_SET(mi,f)	((mi)->windowinfo.flags & f)
+#define MI_FLAG_NOT_SET(mi,f)	( ! MI_FLAG_IS_SET(mi,f))
 #define MI_IS_ICONIC(mi)	(MI_FLAG_IS_SET (mi, WI_FLAG_ICONIC))
 #define MI_IS_MONO(mi)		(MI_FLAG_IS_SET (mi, WI_FLAG_MONO))
 #define MI_IS_INWINDOW(mi)	(MI_FLAG_IS_SET (mi, WI_FLAG_INWINDOW))
@@ -216,7 +216,7 @@ typedef struct ModeInfo_s {
 #define MI_IS_DEBUG(mi)		(MI_FLAG_IS_SET (mi, WI_FLAG_DEBUG))
 #define MI_IS_USE3D(mi)		(MI_FLAG_IS_SET (mi, WI_FLAG_USE3D))
 #define MI_IS_VERBOSE(mi)	(MI_FLAG_IS_SET (mi, WI_FLAG_VERBOSE))
-#define MI_IS_FULLRANDOM(mi) 	(MI_FLAG_IS_SET (mi, WI_FLAG_FULLRANDOM))
+#define MI_IS_FULLRANDOM(mi)	(MI_FLAG_IS_SET (mi, WI_FLAG_FULLRANDOM))
 #define MI_IS_WIREFRAME(mi)	(MI_FLAG_IS_SET (mi, WI_FLAG_WIREFRAME))
 #define MI_IS_FPS(mi)		(MI_FLAG_IS_SET (mi, WI_FLAG_FPS))
 
@@ -333,8 +333,10 @@ extern void release_last_mode(ModeInfo *);
 #ifndef NICE_ONLY
 /* comment out following defines to remove modes */
 #ifdef USE_GL
+#define MODE_bevel
 #define MODE_boxed
 #define MODE_cage
+#define MODE_dino
 #define MODE_fire
 #define MODE_gears
 #ifndef WIN32
@@ -345,12 +347,15 @@ extern void release_last_mode(ModeInfo *);
 #ifdef HAVE_LIBPNG
 #define MODE_maze3d
 #endif
+#define MODE_mball
 #define MODE_moebius
 #ifndef WIN32
 #define MODE_molecule
 #endif
 #define MODE_morph3d
 #define MODE_noof
+#define MODE_oct
+#define MODE_pyraminx
 #define MODE_rubik
 #define MODE_sierpinski3d
 #define MODE_skewb
@@ -662,6 +667,14 @@ extern ModeHook free_bat;
 extern ModeSpecOpt bat_opts;
 #endif
 
+#ifdef MODE_bevel
+extern ModeHook init_bevel;
+extern ModeHook draw_bevel;
+extern ModeHook release_bevel;
+extern ModeHook change_bevel;
+extern ModeSpecOpt bevel_opts;
+#endif
+
 #ifdef MODE_billiards
 extern ModeHook init_billiards;
 extern ModeHook draw_billiards;
@@ -828,6 +841,14 @@ extern ModeHook refresh_dilemma;
 extern ModeSpecOpt dilemma_opts;
 #endif
 
+#ifdef MODE_dino
+extern ModeHook init_dino;
+extern ModeHook draw_dino;
+extern ModeHook release_dino;
+extern ModeHook change_dino;
+extern ModeSpecOpt dino_opts;
+#endif
+
 #ifdef MODE_discrete
 extern ModeHook init_discrete;
 extern ModeHook draw_discrete;
@@ -1201,6 +1222,14 @@ extern ModeHook release_maze3d;
 extern ModeSpecOpt maze3d_opts;
 #endif
 
+#ifdef MODE_mball
+extern ModeHook init_mball;
+extern ModeHook draw_mball;
+extern ModeHook release_mball;
+extern ModeHook change_mball;
+extern ModeSpecOpt mball_opts;
+#endif
+
 #ifdef MODE_moebius
 extern ModeHook init_moebius;
 extern ModeHook draw_moebius;
@@ -1254,6 +1283,14 @@ extern ModeHook refresh_nose;
 extern ModeSpecOpt nose_opts;
 #endif
 
+#ifdef MODE_oct
+extern ModeHook init_oct;
+extern ModeHook draw_oct;
+extern ModeHook release_oct;
+extern ModeHook change_oct;
+extern ModeSpecOpt oct_opts;
+#endif
+
 #ifdef MODE_pacman
 extern ModeHook init_pacman;
 extern ModeHook draw_pacman;
@@ -1318,6 +1355,14 @@ extern ModeHook refresh_puzzle;	/* Needed */
 extern ModeSpecOpt puzzle_opts;
 #endif
 
+#ifdef MODE_pyraminx
+extern ModeHook init_pyraminx;
+extern ModeHook draw_pyraminx;
+extern ModeHook release_pyraminx;
+extern ModeHook change_pyraminx;
+extern ModeSpecOpt pyraminx_opts;
+#endif
+
 #ifdef MODE_pyro
 extern ModeHook init_pyro;
 extern ModeHook draw_pyro;
